Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetTableName ¶
https://github.com/beego/beego/blob/master/client/orm/internal/models/models_utils.go#L74 Cloned from beego source code since it is not exported.
func SnakeString ¶
https://github.com/beego/beego/blob/master/client/orm/internal/models/models_utils.go#L280 Cloned from beego source code since it is not exported.
Types ¶
Click to show internal directories.
Click to hide internal directories.